pub struct NonEmptyRange<T>(Vec<T>);Expand description
Added type safety for objects which are fetched in batches.
A NonEmptyRange has a similar interface as a Vec, but it enforces, via the methods with
which it can be constructed, that the data it contains is always
- at least one object of type
T - a contiguous range of objects ordered by increasing
height.
Tuple Fields
0: Vec<T>Implementations
Sourceimpl<T> NonEmptyRange<T>where
T: HeightIndexed,
impl<T> NonEmptyRange<T>where
T: HeightIndexed,
Sourcepub fn new(elems: impl IntoIterator<Item = T>) -> Result<Self>
pub fn new(elems: impl IntoIterator<Item = T>) -> Result<Self>
Construct a NonEmptyRange from a sequence of elements.
Errors
This constructor will fail if the given sequence is empty, or if its elements do not represent a contiguous range by height.
Sourcepub fn start(&self) -> u64
pub fn start(&self) -> u64
The inclusive lower bound of the range of heights of objects in this NonEmptyRange.
Sourcepub fn end(&self) -> u64
pub fn end(&self) -> u64
The exclusive upper bound of the range of heights of objects in this NonEmptyRange.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
The number of objects in this NonEmptyRange.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Whether the NonEmptyRange is empty.
This function always returns false. It is included only because it is idiomatically
paired with Self::len, as demanded by Clippy.
pub fn iter(&self) -> Iter<'_, T>
Sourcepub(crate) fn as_ref_cloned<U>(&self) -> NonEmptyRange<U>
pub(crate) fn as_ref_cloned<U>(&self) -> NonEmptyRange<U>
Convert a range of objects into an equivalent range of sub-objects with the same heights.